@@ -79,11 +79,11 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "annotated.html",
-"core_8h.html#ae8a7d5be107082a82ccd1fdba6bd56dd",
-"introspect_8c.html#acd6e564b199ca16be48656e77cb5003a",
-"page_proxy.html#sec_page_proxy_bind",
-"rtkit_8h_source.html",
-"structpw__port__events.html#a8459137d0c5f961be6c2747d534313e3"
+"data-loop_8h.html#a6761f26b6c77a8f5ada552077f3fbd2c",
+"introspect_8c.html#a22859b54ffa84b7e4b550eb84eba6d6e",
+"page_client.html#sec_page_client_credentials",
+"resource_8h.html#a7c6de11938397e575506360ba3b8b922",
+"structpw__node__info.html#a737754b76140ca4751f2cd68667ffaa2"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
